@@ -1,8 +1,7 @@
 %% Create files for the currently open figures
-function _make_figs(plot_dir, plot_name, plot_format, plot_offset, plot_res)
+function _make_figs(plot_dir, plot_name, plot_format, plot_offset)
 
 _figHandles = get(0, 'children');
-
 for _fig=1:length(_figHandles),
     _handle = _figHandles(_fig);
     _filename = sprintf('%s/%s%03d.%s', plot_dir, plot_name, _fig + plot_offset, plot_format);
@@ -13,7 +12,8 @@ for _fig=1:length(_figHandles),
        _image = _image ./ (_clim(2) - _clim(1));
        imwrite(uint8(_image*255), _filename);
     catch
-        print(_handle, _filename, sprintf('-r%s', plot_res));
+        print(_handle, _filename);
+    end
     close(_handle);
 end;
 
