@@ -40,6 +40,7 @@ To enable the magics below, execute ``%load_ext octavemagic``.
 #-----------------------------------------------------------------------------
 
 import tempfile
+import codecs
 from glob import glob
 import os
 from shutil import rmtree
@@ -108,7 +109,7 @@ class OctaveMagics(Magics):
             Image width, height.
 
         """
-        (svg,) = minidom.parseString(image).getElementsByTagName('svg')
+        (svg,) = minidom.parseString(image.encode('utf-8')).getElementsByTagName('svg')
         viewbox = svg.getAttribute('viewBox').split(' ')
 
         if size is not None and size[0] is not None:
@@ -324,8 +325,12 @@ class OctaveMagics(Magics):
         images = []
         if not args.gui:
             for imgfile in glob("%s/*" % plot_dir):
-                with open(imgfile, 'rb') as fid:
-                    images.append(fid.read())
+                if plot_format == 'svg':
+                    with codecs.open(imgfile, 'r', encoding='utf-8', errors='replace') as fid:
+                        images.append(fid.read())
+                else:
+                    with open(imgfile, 'rb') as fid:
+                        images.append(fid.read())
             try:
                 rmtree(plot_dir, ignore_errors=True)
             except OSError:
